![pif](https://github.com/hyprland-community/pyprland/assets/238622/ddac10ea-db67-4982-a493-9b45117e5fa7)

## Tweaks & extensions for Hyprland

Host process for multiple Hyprland plugins, such as:

- scratchpads (aka "dropdowns")
- multi-monitor friendly behavior (placement, focus, ...)
- shortcut / togglers for hyprctl commands
- miscelaneous obscure commands for specific usages
- temporary workarounds
- anything you can imagine using [Hyprland API](https://wiki.hyprland.org/Configuring/Dispatchers/) and [events](https://wiki.hyprland.org/Plugins/Development/Event-list/)!

### → Read the [Getting started](https://github.com/hyprland-community/pyprland/wiki/Getting-started) page

### → Open the [plugin list](https://github.com/hyprland-community/pyprland/wiki/Plugins) for more details

### → Check the [Relases](https://github.com/hyprland-community/pyprland/releases) for a change log

### → finally browse the other [wiki](https://github.com/hyprland-community/pyprland/wiki) pages

## Dependencies

- Hyprland >= 0.25
- Python >= 3.11
